@@ -2,7 +2,11 @@ use anyhow::Error;
 use chrono::{DateTime, FixedOffset, NaiveDate, Utc};
 use serde::{Deserialize, Serialize};
 use stack_string::{format_sstr, StackString};
-use std::{collections::BTreeMap, fmt::Write as FmtWrite, io::Write};
+use std::{
+    collections::{BTreeMap, BTreeSet},
+    fmt::Write as FmtWrite,
+    io::Write,
+};
 
 use crate::{
     humidity::Humidity,
@@ -13,7 +17,7 @@ use crate::{
     temperature::Temperature,
     timestamp,
     timezone::TimeZone,
-    weather_data::{Rain, Snow},
+    weather_data::{Rain, Snow, WeatherCond},
 };
 
 #[derive(Deserialize, Serialize, Debug, Clone, Copy)]
@@ -28,11 +32,12 @@ pub struct ForecastMain {
     pub humidity: Humidity,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, Copy)]
+#[derive(Deserialize, Serialize, Debug, Clone)]
 pub struct ForecastEntry {
     #[serde(with = "timestamp")]
     pub dt: DateTime<Utc>,
     pub main: ForecastMain,
+    pub weather: Vec<WeatherCond>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub rain: Option<Rain>,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -62,6 +67,8 @@ impl WeatherForecast {
     /// # use std::fs::File;
     /// # use std::convert::TryFrom;
     /// # use chrono::NaiveDate;
+    /// # use std::collections::BTreeSet;
+    /// # use stack_string::StackString;
     /// use weather_util_rust::weather_forecast::WeatherForecast;
     /// use weather_util_rust::temperature::Temperature;
     /// use weather_util_rust::precipitation::Precipitation;
@@ -73,15 +80,17 @@ impl WeatherForecast {
     ///
     /// let high_low = data.get_high_low();
     /// assert_eq!(high_low.len(), 6);
-    /// let date: NaiveDate = "2020-01-21".parse()?;
+    /// let date: NaiveDate = "2022-02-27".parse()?;
+    /// let icons: BTreeSet<StackString> = ["04n"].iter().map(|s| (*s).into()).collect();
     /// assert_eq!(
     ///     high_low.get(&date),
     ///     Some(
     ///         &(
-    ///             Temperature::try_from(272.65)?,
-    ///             Temperature::try_from(266.76)?,
+    ///             Temperature::try_from(276.76)?,
+    ///             Temperature::try_from(275.01)?,
     ///             Precipitation::default(),
     ///             Precipitation::default(),
+    ///             icons,
     ///         )
     ///     )
     /// );
@@ -90,7 +99,16 @@ impl WeatherForecast {
     /// ```
     pub fn get_high_low(
         &self,
-    ) -> BTreeMap<NaiveDate, (Temperature, Temperature, Precipitation, Precipitation)> {
+    ) -> BTreeMap<
+        NaiveDate,
+        (
+            Temperature,
+            Temperature,
+            Precipitation,
+            Precipitation,
+            BTreeSet<StackString>,
+        ),
+    > {
         let fo: FixedOffset = self.city.timezone.into();
         self.list.iter().fold(BTreeMap::new(), |mut hmap, entry| {
             let date = entry.dt.with_timezone(&fo).date().naive_local();
@@ -106,18 +124,25 @@ impl WeatherForecast {
             } else {
                 Precipitation::default()
             };
+            let mut icons: BTreeSet<StackString> =
+                entry.weather.iter().map(|w| w.icon.clone()).collect();
 
-            if let Some((h, l, r, s)) = hmap.get(&date) {
+            if let Some((h, l, r, s, i)) = hmap.get(&date) {
                 let high = if high > *h { high } else { *h };
                 let low = if low < *l { low } else { *l };
                 let rain = *r + rain;
                 let snow = *s + snow;
+                for ic in i {
+                    if !icons.contains(ic) {
+                        icons.insert(ic.clone());
+                    }
+                }
 
                 if (high, low) != (*h, *l) {
-                    hmap.insert(date, (high, low, rain, snow));
+                    hmap.insert(date, (high, low, rain, snow, icons));
                 }
             } else {
-                hmap.insert(date, (high, low, rain, snow));
+                hmap.insert(date, (high, low, rain, snow, icons));
             }
             hmap
         })
@@ -140,14 +165,14 @@ impl WeatherForecast {
     /// let buf = data.get_forecast()?.join("");
     ///
     /// assert!(buf.starts_with("\nForecast:"), buf);
-    /// assert!(buf.contains("2020-01-23 High: 37.7 F / 3.2 C"));
-    /// assert!(buf.contains("Low: 30.1 F / -1.1 C"));
+    /// assert!(buf.contains("2022-02-27 High: 38.5 F / 3.6 C"));
+    /// assert!(buf.contains("Low: 35.3 F / 1.9 C"));
     /// # Ok(())
     /// # }
     /// ```
     pub fn get_forecast(&self) -> Result<Vec<String>, Error> {
         let mut output = vec!["\nForecast:\n".into()];
-        output.extend(self.get_high_low().into_iter().map(|(d, (h, l, r, s))| {
+        output.extend(self.get_high_low().into_iter().map(|(d, (h, l, r, s, _))| {
             let high = format_sstr!("High: {:0.1} F / {:0.1} C", h.fahrenheit(), h.celcius());
             let low = format_sstr!("Low: {:0.1} F / {:0.1} C", l.fahrenheit(), l.celcius());
             let mut rain_snow = StackString::new();
@@ -170,7 +195,8 @@ impl WeatherForecast {
 mod test {
     use anyhow::Error;
     use chrono::NaiveDate;
-    use std::convert::TryFrom;
+    use stack_string::StackString;
+    use std::{collections::BTreeSet, convert::TryFrom};
 
     use crate::{
         precipitation::Precipitation, temperature::Temperature, weather_forecast::WeatherForecast,
@@ -182,14 +208,16 @@ mod test {
         let data: WeatherForecast = serde_json::from_str(&buf)?;
         let high_low = data.get_high_low();
         assert_eq!(high_low.len(), 6);
-        let date: NaiveDate = "2020-01-21".parse()?;
+        let date: NaiveDate = "2022-02-27".parse()?;
+        let icons: BTreeSet<StackString> = ["04n"].iter().map(|s| (*s).into()).collect();
         assert_eq!(
             high_low.get(&date),
             Some(&(
-                Temperature::try_from(272.65)?,
-                Temperature::try_from(266.76)?,
+                Temperature::try_from(276.76)?,
+                Temperature::try_from(275.01)?,
                 Precipitation::default(),
                 Precipitation::default(),
+                icons,
             ))
         );
 
@@ -204,8 +232,8 @@ mod test {
         let buf = forecasts.join("");
         println!("{}", buf);
         assert!(buf.starts_with("\nForecast:"));
-        assert!(buf.contains("2020-01-23 High: 37.7 F / 3.2 C"));
-        assert!(buf.contains("Low: 30.1 F / -1.1 C"));
+        assert!(buf.contains("2022-02-27 High: 38.5 F / 3.6 C"));
+        assert!(buf.contains("Low: 35.3 F / 1.9 C"));
         for f in forecasts {
             println!("{}", f.len());
         }
